@@ -38,4 +38,4 @@ def disjunctor1():
     # search
     s.branch([x,y],INT_VAR_SIZE_MIN,INT_VAL_MIN)
     for sol in s.search():
-        print sol.val([x,y])
+        print(sol.val([x,y]))
