@@ -34,4 +34,4 @@ def send_more_money():
     s.linear(C,X,IRT_EQ,0)
     s.branch(letters,INT_VAR_SIZE_MIN,INT_VAL_MIN)
     for s2 in s.search():
-        print s2.val(letters)
+        print(s2.val(letters))
